==> python-dateparser-1.0.0-2-any.pkg.tar.xz: usr/lib/python3.9/site-packages/dateparser/data/date_translation_data/gu.py <==
info = {
    "name": "gu",
    "date_order": "DMY",
    "january": [
        "જાન્યુઆરી",
        "જાન્યુ"
    ],
    "february": [
        "ફેબ્રુઆરી",
        "ફેબ્રુ"
    ],
    "march": [
        "માર્ચ"
    ],
    "april": [
        "એપ્રિલ"
    ],
    "may": [
        "મે"
    ],
    "june": [
        "જૂન"
    ],
    "july": [
        "જુલાઈ"
    ],
    "august": [
        "ઑગસ્ટ"
    ],
    "september": [
        "સપ્ટેમ્બર",
        "સપ્ટે"
    ],
    "october": [
        "ઑક્ટોબર",
        "ઑક્ટો"
    ],
    "november": [
        "નવેમ્બર",
        "નવે"
    ],
    "december": [
        "ડિસેમ્બર",
        "ડિસે"
    ],
    "monday": [
        "સોમવાર",
        "સોમ"
    ],
    "tuesday": [
        "મંગળવાર",
        "મંગળ"
    ],
    "wednesday": [
        "બુધવાર",
        "બુધ"
    ],
    "thursday": [
        "ગુરુવાર",
        "ગુરુ"
    ],
    "friday": [
        "શુક્રવાર",
        "શુક્ર"
    ],
    "saturday": [
        "શનિવાર",
        "શનિ"
    ],
    "sunday": [
        "રવિવાર",
        "રવિ"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "વર્ષ",
        "વ"
    ],
    "month": [
        "મહિનો",
        "મ"
    ],
    "week": [
        "અઠવાડિયું",
        "અઠ"
    ],
    "day": [
        "દિવસ"
    ],
    "hour": [
        "કલાક",
        "ક"
    ],
    "minute": [
        "મિનિટ",
        "મિ"
    ],
    "second": [
        "સેકન્ડ",
        "સે"
    ],
    "relative-type": {
        "1 year ago": [
            "ગયા વર્ષે"
        ],
        "0 year ago": [
            "આ વર્ષે"
        ],
        "in 1 year": [
            "આવતા વર્ષે"
        ],
        "1 month ago": [
            "ગયા મહિને"
        ],
        "0 month ago": [
            "આ મહિને"
        ],
        "in 1 month": [
            "આવતા મહિને"
        ],
        "1 week ago": [
            "ગયા અઠવાડિયે"
        ],
        "0 week ago": [
            "આ અઠવાડિયે"
        ],
        "in 1 week": [
            "આવતા અઠવાડિયે"
        ],
        "1 day ago": [
            "ગઈકાલે"
        ],
        "0 day ago": [
            "આજે"
        ],
        "in 1 day": [
            "આવતીકાલે"
        ],
        "0 hour ago": [
            "આ કલાક"
        ],
        "0 minute ago": [
            "આ મિનિટ"
        ],
        "0 second ago": [
            "હમણાં"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) વર્ષમાં"
        ],
        "\\1 year ago": [
            "(\\d+) વર્ષ પહેલાં",
            "(\\d+) વર્ષ પહેલા"
        ],
        "in \\1 month": [
            "(\\d+) મહિનામાં"
        ],
        "\\1 month ago": [
            "(\\d+) મહિના પહેલાં"
        ],
        "in \\1 week": [
            "(\\d+) અઠવાડિયામાં",
            "(\\d+) અઠ માં"
        ],
        "\\1 week ago": [
            "(\\d+) અઠવાડિયા પહેલાં",
            "(\\d+) અઠ પહેલાં"
        ],
        "in \\1 day": [
            "(\\d+) દિવસમાં"
        ],
        "\\1 day ago": [
            "(\\d+) દિવસ પહેલાં"
        ],
        "in \\1 hour": [
            "(\\d+) કલાકમાં"
        ],
        "\\1 hour ago": [
            "(\\d+) કલાક પહેલાં"
        ],
        "in \\1 minute": [
            "(\\d+) મિનિટમાં"
        ],
        "\\1 minute ago": [
            "(\\d+) મિનિટ પહેલાં"
        ],
        "in \\1 second": [
            "(\\d+) સેકંડમાં"
        ],
        "\\1 second ago": [
            "(\\d+) સેકંડ પહેલાં"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/gu.py <==
info = {
    "name": "gu",
    "date_order": "DMY",
    "january": [
        "જાન્યુ",
        "જાન્યુઆરી"
    ],
    "february": [
        "ફેબ્રુ",
        "ફેબ્રુઆરી"
    ],
    "march": [
        "માર્ચ"
    ],
    "april": [
        "એપ્રિલ"
    ],
    "may": [
        "મે"
    ],
    "june": [
        "જૂન"
    ],
    "july": [
        "જુલાઈ"
    ],
    "august": [
        "ઑગસ્ટ"
    ],
    "september": [
        "સપ્ટે",
        "સપ્ટેમ્બર"
    ],
    "october": [
        "ઑક્ટો",
        "ઑક્ટોબર"
    ],
    "november": [
        "નવે",
        "નવેમ્બર"
    ],
    "december": [
        "ડિસે",
        "ડિસેમ્બર"
    ],
    "monday": [
        "સોમ",
        "સોમવાર"
    ],
    "tuesday": [
        "મંગળ",
        "મંગળવાર"
    ],
    "wednesday": [
        "બુધ",
        "બુધવાર"
    ],
    "thursday": [
        "ગુરુ",
        "ગુરુવાર"
    ],
    "friday": [
        "શુક્ર",
        "શુક્રવાર"
    ],
    "saturday": [
        "શનિ",
        "શનિવાર"
    ],
    "sunday": [
        "રવિ",
        "રવિવાર"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "વ",
        "વર્ષ"
    ],
    "month": [
        "મ",
        "મહિનો"
    ],
    "week": [
        "અઠ",
        "અઠવાડિયું"
    ],
    "day": [
        "દિવસ"
    ],
    "hour": [
        "ક",
        "કલાક"
    ],
    "minute": [
        "મિ",
        "મિનિટ"
    ],
    "second": [
        "સે",
        "સેકન્ડ"
    ],
    "relative-type": {
        "0 day ago": [
            "આજે"
        ],
        "0 hour ago": [
            "આ કલાક"
        ],
        "0 minute ago": [
            "આ મિનિટ"
        ],
        "0 month ago": [
            "આ મહિને"
        ],
        "0 second ago": [
            "હમણાં"
        ],
        "0 week ago": [
            "આ અઠવાડિયે"
        ],
        "0 year ago": [
            "આ વર્ષે"
        ],
        "1 day ago": [
            "ગઈકાલે"
        ],
        "1 month ago": [
            "ગયા મહિને"
        ],
        "1 week ago": [
            "ગયા અઠવાડિયે"
        ],
        "1 year ago": [
            "ગયા વર્ષે"
        ],
        "in 1 day": [
            "આવતીકાલે"
        ],
        "in 1 month": [
            "આવતા મહિને"
        ],
        "in 1 week": [
            "આવતા અઠવાડિયે"
        ],
        "in 1 year": [
            "આવતા વર્ષે"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) દિવસ પહેલાં"
        ],
        "\\1 hour ago": [
            "(\\d+) કલાક પહેલાં"
        ],
        "\\1 minute ago": [
            "(\\d+) મિનિટ પહેલાં"
        ],
        "\\1 month ago": [
            "(\\d+) મહિના પહેલાં"
        ],
        "\\1 second ago": [
            "(\\d+) સેકંડ પહેલાં"
        ],
        "\\1 week ago": [
            "(\\d+) અઠ પહેલાં",
            "(\\d+) અઠવાડિયા પહેલાં"
        ],
        "\\1 year ago": [
            "(\\d+) વર્ષ પહેલા",
            "(\\d+) વર્ષ પહેલાં"
        ],
        "in \\1 day": [
            "(\\d+) દિવસમાં"
        ],
        "in \\1 hour": [
            "(\\d+) કલાકમાં"
        ],
        "in \\1 minute": [
            "(\\d+) મિનિટમાં"
        ],
        "in \\1 month": [
            "(\\d+) મહિનામાં"
        ],
        "in \\1 second": [
            "(\\d+) સેકંડમાં"
        ],
        "in \\1 week": [
            "(\\d+) અઠ માં",
            "(\\d+) અઠવાડિયામાં"
        ],
        "in \\1 year": [
            "(\\d+) વર્ષમાં"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
